﻿using Microsoft.EntityFrameworkCore;
using MySQL.Data.EntityFrameworkCore.Extensions;
using MySql.Data.MySqlClient;

namespace blogsample
{
    public class BlogDbContext : DbContext
    {
        public DbSet<Blog> Blogs { get; set; }
        public DbSet<Category> Categories { get; set; }
        
        public BlogDbContext(string profile) : base()
        {
            m_profile = profile;
        }

        protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
        {
            optionsBuilder.UseMySQL(GetConnectionString());
        }

        protected override void OnModelCreating(ModelBuilder modelBuilder)
        {   
            // comments
            modelBuilder.Entity<Blog>()
                .HasMany(b => b.Comments)
                .WithOne(c => c.Blog)
                .HasForeignKey(c => c.BlogId);

            // categories
            modelBuilder.Entity<BlogCategory>().HasKey(t => new { t.BlogId, t.CategoryId });

            modelBuilder.Entity<BlogCategory>()
                .HasOne(pt => pt.Blog)
                .WithMany(p => p.BlogsCategories)
                .HasForeignKey(pt => pt.BlogId);

            modelBuilder.Entity<BlogCategory>()
                .HasOne(pt => pt.Category)
                .WithMany(t => t.BlogsCategories)
                .HasForeignKey(pt => pt.CategoryId);
        }

        private string m_profile = null;

        private string GetConnectionString()
        {
            if (m_profile == "local")
            {
                return new MySqlConnectionStringBuilder
                {
                    Server = "localhost",
                    Database = "BlogDb",
                    Port = 3306,
                    SslMode = MySqlSslMode.None,
                    UserID = "siddharth",
                    Password = "*******"
                }.ConnectionString;
            }
            else
            {
                return new MySqlConnectionStringBuilder
                {
                    Server = "******.us-east-1.rds.amazonaws.com",
                    Database = "BlogDb",
                    Port = 0,
                    SslMode = MySqlSslMode.None,
                    UserID = "******",
                    Password = "******"
                }.ConnectionString;
            }
        }
    }
}
